function [x] = Andrzejak_PRE_90_062906_RungeKuttaIntegrator(deriv,N,dt,initialconditions)
% This source code forms part of the resources provided at http://ntsa.upf.edu/downloads .
% It belongs to the library used for the computations underlying the manuscript:
% Andrzejak RG, Mormann F, Kreuz T.  2014.  Detecting determinism from point processes. Phys. Rev. E. 90, 062906
% In order to understand how the source code works, you should at first
% read the manuscript. A preprint can be found following the link above.
% If you use the source codes, please make sure that you give a reference to
% the manuscript. The correct way to cite this paper is shown above.
% No page numbers should be given in the reference.
% +++ What this particular script does:
%
%
% Integration of ODEs using 4th order Runge-Kutta, fixed step size
% 
% +++Input+++
% @deriv: specifies the script of the derivative
% N: Number of datapoints
% dt: time step
% initialconditions: initial conditions 

x = zeros(size(initialconditions,1),N);
x(:,1) = initialconditions;

for j=2:N
    k1 = dt*feval(deriv,x(:,j-1));
    k2 = dt*feval(deriv,x(:,j-1)+k1/2);
    k3 = dt*feval(deriv,x(:,j-1)+k2/2);
    k4 = dt*feval(deriv,x(:,j-1)+k3);
    x(:,j) = x(:,j-1) + k1/6+k2/3+k3/3+k4/6;
end

